@@ -18,6 +18,8 @@ import traceback
 
 import shutil, tarfile
 
+import json
+
 import importlib.resources as pkg_resources
 from io import StringIO
 
@@ -421,13 +423,34 @@ def convert_raw_df_into_final_df(df_raw, metric):
 def compile_dataframe_for_all_datasets_on_metric(openmlids, metric):
     df_results = None
     for openmlid in tqdm(openmlids):
-        df_results_tmp = convert_raw_df_into_final_df(get_raw_df(openmlid), metric)
-        df_results = df_results_tmp if df_results is None else pd.concat([df_results, df_results_tmp])
+        print(openmlid)
+        try:
+            df_results_tmp = convert_raw_df_into_final_df(get_raw_df(openmlid), metric)
+            df_results = df_results_tmp if df_results is None else pd.concat([df_results, df_results_tmp])
+        except:
+            print("ERROR")
     return df_results
 
 
+'''
+    gets the full local database of learning curves as a dataframe
+'''
 def get_all_curves(metric = "accuracy"):
     supported_metrics = ["accuracy", "logloss"]
     if not metric in supported_metrics:
         raise ValueError(f"Unsupported metric {metric}. Supported metrics are {supported_metrics}")
-    return pd.read_csv(StringIO(pkg_resources.read_text('lcdb', f'database-{metric}.csv')))
\ No newline at end of file
+    return pd.read_csv(StringIO(pkg_resources.read_text('lcdb', f'database-{metric}.csv')))
+
+'''
+    gets the anchors and train, validation, and test performances of the learner on the given dataset.
+    It is just a shortcut for retrieval from the dataframe.
+'''
+def get_curve(openmlid, learner, metric = "accuracy"):
+    df = get_all_curves(metric)
+    df = df[(df["openmlid"] == openmlid)]
+    if len(df) == 0:
+        raise Exception(f"No curves found for openmlid {openmlid}")
+    df = df[(df["learner"] == learner)]
+    if len(df) == 0:
+        raise Exception(f"No curves found for learner {learner} on openmlid {openmlid}")
+    return get_curve_from_dataframe(df)
\ No newline at end of file
